package java.awt;

import java.awt.geom.AffineTransform;
import sun.awt.image.SunVolatileImage;
import java.awt.image.VolatileImage;
import java.awt.image.ColorModel;
import java.awt.image.BufferedImage;

public abstract class GraphicsConfiguration
{
    private static BufferCapabilities defaultBufferCaps;
    private static ImageCapabilities defaultImageCaps;
    
    protected GraphicsConfiguration() {
    }
    
    public abstract GraphicsDevice getDevice();
    
    public BufferedImage createCompatibleImage(int w, int h) {
        ColorModel colorModel = this.getColorModel();
        return new BufferedImage(colorModel, colorModel.createCompatibleWritableRaster(w, h), colorModel.isAlphaPremultiplied(), null);
    }
    
    public BufferedImage createCompatibleImage(int w, int h, int i) {
        if (this.getColorModel().getTransparency() == i) {
            return this.createCompatibleImage(w, h);
        }
        ColorModel colorModel = this.getColorModel(i);
        if (colorModel == null) {
            throw new IllegalArgumentException("Unknown transparency: " + i);
        }
        return new BufferedImage(colorModel, colorModel.createCompatibleWritableRaster(w, h), colorModel.isAlphaPremultiplied(), null);
    }
    
    public VolatileImage createCompatibleVolatileImage(int n, int n2) {
        VolatileImage compatibleVolatileImage = null;
        try {
            compatibleVolatileImage = this.createCompatibleVolatileImage(n, n2, null, 1);
        }
        catch (AWTException ex) {
            assert false;
        }
        return compatibleVolatileImage;
    }
    
    public VolatileImage createCompatibleVolatileImage(int n, int n2, int n3) {
        VolatileImage compatibleVolatileImage = null;
        try {
            compatibleVolatileImage = this.createCompatibleVolatileImage(n, n2, null, n3);
        }
        catch (AWTException ex) {
            assert false;
        }
        return compatibleVolatileImage;
    }
    
    public VolatileImage createCompatibleVolatileImage(int n, int n2, ImageCapabilities imageCapabilities) throws AWTException {
        return this.createCompatibleVolatileImage(n, n2, imageCapabilities, 1);
    }
    
    public VolatileImage createCompatibleVolatileImage(int width, int height, ImageCapabilities caps, int transparency) throws AWTException {
        SunVolatileImage sunVolatileImage = new SunVolatileImage(this, width, height, transparency, caps);
        if (caps != null && caps.isAccelerated() && !sunVolatileImage.getCapabilities().isAccelerated()) {
            throw new AWTException("Supplied image capabilities could not be met by this graphics configuration.");
        }
        return sunVolatileImage;
    }
    
    public abstract ColorModel getColorModel();
    
    public abstract ColorModel getColorModel(int p0);
    
    public abstract AffineTransform getDefaultTransform();
    
    public abstract AffineTransform getNormalizingTransform();
    
    public abstract Rectangle getBounds();
    
    public BufferCapabilities getBufferCapabilities() {
        if (GraphicsConfiguration.defaultBufferCaps == null) {
            GraphicsConfiguration.defaultBufferCaps = new GraphicsConfiguration.DefaultBufferCapabilities(this.getImageCapabilities());
        }
        return GraphicsConfiguration.defaultBufferCaps;
    }
    
    public ImageCapabilities getImageCapabilities() {
        if (GraphicsConfiguration.defaultImageCaps == null) {
            GraphicsConfiguration.defaultImageCaps = new ImageCapabilities(false);
        }
        return GraphicsConfiguration.defaultImageCaps;
    }
    
    public boolean isTranslucencyCapable() {
        return false;
    }
    
    private static class DefaultBufferCapabilities extends BufferCapabilities
    {
        public DefaultBufferCapabilities(ImageCapabilities imageCapabilities) {
            super(imageCapabilities, imageCapabilities, null);
        }
    }
}
